==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForServersGcpOfferingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Configuration for servers Arc auto provisioning
 * @property privateLinkScope Optional Arc private link scope resource id to link the Arc agent
 * @property proxy Optional HTTP proxy endpoint to use for the Arc agent
 */
public data class DefenderForServersGcpOfferingConfigurationArgs(
    public val privateLinkScope: Output<String>? = null,
    public val proxy: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs =
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs.builder()
            .privateLinkScope(privateLinkScope?.applyValue({ args0 -> args0 }))
            .proxy(proxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForServersGcpOfferingConfigurationArgs].
 */
@PulumiTagMarker
public class DefenderForServersGcpOfferingConfigurationArgsBuilder internal constructor() {
    private var privateLinkScope: Output<String>? = null

    private var proxy: Output<String>? = null

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("kjpubfjtwwxubefl")
    public suspend fun privateLinkScope(`value`: Output<String>) {
        this.privateLinkScope = value
    }

    /**
     * @param value Optional HTTP proxy endpoint to use for the Arc agent
     */
    @JvmName("phybmfrnoeijetyx")
    public suspend fun proxy(`value`: Output<String>) {
        this.proxy = value
    }

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("ptbaerfsqrhcglob")
    public suspend fun privateLinkScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkScope = mapped
    }

    /**
     * @param value Optional HTTP proxy endpoint to use for the Arc agent
     */
    @JvmName("qoyhlirxwkcwcrlm")
    public suspend fun proxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.proxy = mapped
    }

    internal fun build(): DefenderForServersGcpOfferingConfigurationArgs =
        DefenderForServersGcpOfferingConfigurationArgs(
            privateLinkScope = privateLinkScope,
            proxy = proxy,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForServersGcpOfferingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Configuration for servers Arc auto provisioning
 * @property privateLinkScope Optional Arc private link scope resource id to link the Arc agent
 * @property proxy Optional HTTP proxy endpoint to use for the Arc agent
 */
public data class DefenderForServersGcpOfferingConfigurationArgs(
    public val privateLinkScope: Output<String>? = null,
    public val proxy: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs =
        com.pulumi.azurenative.security.inputs.DefenderForServersGcpOfferingConfigurationArgs.builder()
            .privateLinkScope(privateLinkScope?.applyValue({ args0 -> args0 }))
            .proxy(proxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForServersGcpOfferingConfigurationArgs].
 */
@PulumiTagMarker
public class DefenderForServersGcpOfferingConfigurationArgsBuilder internal constructor() {
    private var privateLinkScope: Output<String>? = null

    private var proxy: Output<String>? = null

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("ywpqddubjhludxmx")
    public suspend fun privateLinkScope(`value`: Output<String>) {
        this.privateLinkScope = value
    }

    /**
     * @param value Optional HTTP proxy endpoint to use for the Arc agent
     */
    @JvmName("isyclalunkfmmhjk")
    public suspend fun proxy(`value`: Output<String>) {
        this.proxy = value
    }

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("higyrxbcxoxqnjjv")
    public suspend fun privateLinkScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkScope = mapped
    }

    /**
     * @param value Optional HTTP proxy endpoint to use for the Arc agent
     */
    @JvmName("uuvxqfuxkjrwpwjq")
    public suspend fun proxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.proxy = mapped
    }

    internal fun build(): DefenderForServersGcpOfferingConfigurationArgs =
        DefenderForServersGcpOfferingConfigurationArgs(
            privateLinkScope = privateLinkScope,
            proxy = proxy,
        )
}
